@@ -1,6 +1,6 @@
 package Mason::t::Request;
 BEGIN {
-  $Mason::t::Request::VERSION = '2.01';
+  $Mason::t::Request::VERSION = '2.02';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 use Log::Any::Test;
@@ -74,6 +74,14 @@ sub test_page : Test(1) {
     );
 }
 
+sub test_result_data : Test(1) {
+    my $self = shift;
+    $self->test_comp(
+        src         => '% $m->result->data->{color} = "red"',
+        expect_data => { color => "red" }
+    );
+}
+
 sub test_subrequest : Test(4) {
     my $self = shift;
 
